<?php

class AuthController extends Zend_Controller_Action
{

	public function indexAction()
	{
		$this->_helper->redirector('login');
	}

	public function loginAction()
	{
		// проверяем, авторизирован ли пользователь
		if (Zend_Auth::getInstance()->hasIdentity()) {
			// если да, то делаем редирект, чтобы исключить многократную авторизацию
			$this->_helper->redirector('index', 'index');
		}

		// создаём форму и передаём её во view
		$form = new Application_Form_Login();
		$this->view->form = $form;

		// Если к нам идёт Post запрос
		if ($this->getRequest()->isPost()) {
			// Принимаем его
			$formData = $this->getRequest()->getPost();

			// Если форма заполнена верно
			if ($form->isValid($formData)) {
				$dbAdapter = Zend_Controller_Front::getInstance()->getParam('bootstrap')->getPluginResource('multidb')->getDb('realmd');
				// Получаем адаптер подключения к базе данных
				$authAdapter = new Zend_Auth_Adapter_DbTable($dbAdapter);
				// указываем таблицу, где необходимо искать данные о пользователях
				// колонку, где искать имена пользователей,
				// а также колонку, где хранятся пароли
				$authAdapter->setTableName('account')
				->setIdentityColumn('username')
				->setCredentialColumn('sha_pass_hash');
				
				// получаем введённые данные
				$values = $form->getValues();
				// подставляем полученные данные из формы
				$authAdapter->setIdentity($values['username'])
				->setCredentialTreatment("SHA1(CONCAT('{$values['username']}:', ?))")
				->setCredential($values['password']);

				// получаем экземпляр Zend_Auth
				$auth = Zend_Auth::getInstance();
				
				// делаем попытку авторизировать пользователя
				$result = $auth->authenticate($authAdapter);

				// если авторизация прошла успешно
				if ($result->isValid()) {
					// используем адаптер для извлечения оставшихся данных о пользователе
					$identity = $authAdapter->getResultRowObject(null, 'sha_pass_hash');
					// получаем доступ к хранилищу данных Zend
					$authStorage = $auth->getStorage();
					// помещаем туда информацию о пользователе,
					// чтобы иметь к ним доступ при конфигурировании Acl
					$authStorage->write($identity);
					// Используем библиотечный helper для редиректа
					// на controller = index, action = index
					$this->_helper->redirector('index', 'index');
				} else {
					$this->view->errMessage = 'Вы ввели неверное имя пользователя или неверный пароль';
				}
			}
		}
	}


	public function logoutAction()
	{
		// уничтожаем информацию об авторизации пользователя
		Zend_Auth::getInstance()->clearIdentity();

		// и отправляем его на главную
		$this->_helper->redirector('index', 'index');
	}

	public function registrationAction()
	{
		// проверяем, авторизирован ли пользователь
		if (Zend_Auth::getInstance()->hasIdentity()) {
			// если да, то делаем редирект, чтобы исключить многократную регистрацию
			$this->_helper->redirector('index', 'index');
		}
		// создаём форму и передаём её во view
		$form = new Application_Form_Registration();
		$this->view->form = $form;

		// Если к нам идёт Post запрос
		if ($this->getRequest()->isPost()) {
			// Принимаем его
			$formData = $this->getRequest()->getPost();
			// Если форма заполнена верно
			if ($form->isValid($formData)) {
				// Получаем адаптер подключения к базе данных
				$dbAdapter = Zend_Controller_Front::getInstance()->getParam('bootstrap')->getPluginResource('multidb')->getDb('realmd');
				// получаем введённые данные
				$values = $form->getValues();
				$valuesfull = $form->getUnfilteredValues();
				$data = array('username' => $valuesfull['username'],
	                  			'sha_pass_hash' => SHA1($values['username'].':'.$values['password']), 
	                 			'email' => $values['email'], 
	                 			'expansion' => 2 
				);
				$result = $dbAdapter->insert('account', $data);
				$this->_helper->redirector('index', 'index');
			}
		}
	}

}
